@@ -8,7 +8,7 @@ from manufacturers.models import ManufacturerField
 from stock.models import Stock, UnitType
 from product_barcode.models import BarCodeField
 
-from tecdoc.models import AdditionalCodesField
+from tecdoc.models import AdditionalCodesField, Tecdoc
 from tecdoc.utils import clean_code
 
 from exchange.models import MultiCurrencyPrice, subscribe_on_exchange_rates
@@ -18,7 +18,7 @@ from products.managers import ProductManager
 
 
 @subscribe_on_exchange_rates
-class Product(MultiCurrencyPrice, Stock, UnitType):
+class Product(MultiCurrencyPrice, Stock, UnitType, Tecdoc):
 
     is_active = models.BooleanField(_('Is active'), default=True)
 
@@ -26,11 +26,6 @@ class Product(MultiCurrencyPrice, Stock, UnitType):
 
     category = CategoryField(related_name='products')
 
-    article_number = models.CharField(max_length=100, blank=True, null=True)
-    supplier_id = models.IntegerField(blank=True, null=True)
-    tecdoc_description = models.TextField(
-        max_length=10000, blank=True, editable=False)
-
     name = models.CharField(
         _('Product name'), max_length=255, blank=True, db_index=True)
 
@@ -40,8 +35,6 @@ class Product(MultiCurrencyPrice, Stock, UnitType):
 
     bar_code = BarCodeField()
 
-    additional_codes = AdditionalCodesField()
-
     warehouse = models.CharField(
         _('Warehouse location'), max_length=255, blank=True)
 
@@ -81,9 +74,6 @@ class Product(MultiCurrencyPrice, Stock, UnitType):
             'stock': self.stock
         }
 
-    def has_article(self):
-        return bool(self.article_number and self.supplier_id)
-
     class Meta:
         ordering = ['-id']
         verbose_name = _('Product')
